@@ -22,6 +22,7 @@ FEED_EXTRA_FIELDS = ("method", "product_id", "timezone")
 # Extra fields added to items (events) to
 # support ical
 ICAL_EXTRA_FIELDS = [
+    "component_type", # type of calendar component (event, todo)
     "timestamp",  # dtstamp
     "created",  # created
     "start_datetime",  # dtstart
@@ -36,7 +37,12 @@ ICAL_EXTRA_FIELDS = [
     "exdate",  # exdate
     "status",  # CONFIRMED|TENTATIVE|CANCELLED
     "attendee",  # list of attendees
-    "valarm",  # list of icalendar.Alarm objects
+    "valarm",  # list of icalendar.Alarm objects,
+    # additional fields for tasks
+    "completed", # completed
+    "percent_complete", # percent-complete
+    "priority", # priority
+    "due", # due
 ]
 
 
@@ -78,8 +84,8 @@ class ICalFeed(Feed):
         """
         try:
             obj = self.get_object(request, *args, **kwargs)
-        except ObjectDoesNotExist:
-            raise Http404("Feed object does not exist.")
+        except ObjectDoesNotExist as exc:
+            raise Http404("Feed object does not exist.") from exc
 
         feedgen = self.get_feed(obj, request)
         response = HttpResponse(content_type=feedgen.mime_type)
@@ -94,7 +100,7 @@ class ICalFeed(Feed):
 
         filename = self._get_dynamic_attr("file_name", obj)
         if filename:
-            response["Content-Disposition"] = 'attachment; filename="%s"' % filename
+            response["Content-Disposition"] = f'attachment; filename="{filename}"'
 
         return response
 
